@@ -344,10 +344,9 @@
       request.send(null);
       if (request.status === 200) {
         return request.responseText;
-      } else {
-        console.error('Error while decoding chunk in streamWrite');
-        return '';
       }
+      console.error('Error while decoding chunk in streamWrite');
+      return '';
     }
   };
 
@@ -356,6 +355,35 @@
 
   // InspectorFrontendHostImpl --------------------------------------------------
 
+  /**
+   * Enum for recordPerformanceHistogram
+   * Warning: There are two other definitions of this enum in the DevTools code
+   * base, keep them in sync:
+   * front_end/extern.js
+   * front_end/host/InspectorFrontendHostAPI.js
+   * @readonly
+   * @enum {string}
+   */
+  const EnumeratedHistogram = {
+    ActionTaken: 'DevTools.ActionTaken',
+    ColorPickerFixedColor: 'DevTools.ColorPicker.FixedColor',
+    PanelClosed: 'DevTools.PanelClosed',
+    PanelShown: 'DevTools.PanelShown',
+    SidebarPaneShown: 'DevTools.SidebarPaneShown',
+    KeyboardShortcutFired: 'DevTools.KeyboardShortcutFired',
+    IssuesPanelIssueExpanded: 'DevTools.IssuesPanelIssueExpanded',
+    IssuesPanelOpenedFrom: 'DevTools.IssuesPanelOpenedFrom',
+    IssuesPanelResourceOpened: 'DevTools.IssuesPanelResourceOpened',
+    KeybindSetSettingChanged: 'DevTools.KeybindSetSettingChanged',
+    DualScreenDeviceEmulated: 'DevTools.DualScreenDeviceEmulated',
+    CSSGridSettings: 'DevTools.CSSGridSettings2',
+    HighlightedPersistentCSSGridCount: 'DevTools.HighlightedPersistentCSSGridCount',
+    ExperimentEnabledAtLaunch: 'DevTools.ExperimentEnabledAtLaunch',
+    ExperimentEnabled: 'DevTools.ExperimentEnabled',
+    ExperimentDisabled: 'DevTools.ExperimentDisabled',
+    GridOverlayOpenedFrom: 'DevTools.GridOverlayOpenedFrom',
+  };
+
   /**
    * @implements {InspectorFrontendHostAPI}
    * @unrestricted
@@ -434,6 +462,24 @@
       DevToolsAPI.sendMessageToEmbedder('setIsDocked', [isDocked], callback);
     }
 
+    /**
+     * @override
+     * @param {string} trigger
+     * @param {function(!InspectorFrontendHostAPI.ShowSurveyResult): void} callback
+     */
+    showSurvey(trigger, callback) {
+      DevToolsAPI.sendMessageToEmbedder('showSurvey', [trigger], /** @type {function(?Object)} */ (callback));
+    }
+
+    /**
+     * @override
+     * @param {string} trigger
+     * @param {function(!InspectorFrontendHostAPI.CanShowSurveyResult): void} callback
+     */
+    canShowSurvey(trigger, callback) {
+      DevToolsAPI.sendMessageToEmbedder('canShowSurvey', [trigger], /** @type {function(?Object)} */ (callback));
+    }
+
     /**
      * Requests inspected page to be placed atop of the inspector frontend with specified bounds.
      * @override
@@ -455,7 +501,7 @@
      * @param {string} url
      * @param {string} headers
      * @param {number} streamId
-     * @param {function(!InspectorFrontendHostAPI.LoadNetworkResourceResult)} callback
+     * @param {function(!InspectorFrontendHostAPI.LoadNetworkResourceResult): void} callback
      */
     loadNetworkResource(url, headers, streamId, callback) {
       DevToolsAPI.sendMessageToEmbedder(
@@ -571,13 +617,12 @@
 
     /**
      * @override
-     * @param {string} actionName
+     * @param {!InspectorFrontendHostAPI.EnumeratedHistogram} actionName
      * @param {number} actionCode
      * @param {number} bucketSize
      */
     recordEnumeratedHistogram(actionName, actionCode, bucketSize) {
-      // Support for M49 frontend.
-      if (actionName === 'DevTools.DrawerShown') {
+      if (!Object.values(EnumeratedHistogram).includes(actionName)) {
         return;
       }
       DevToolsAPI.sendMessageToEmbedder('recordEnumeratedHistogram', [actionName, actionCode, bucketSize], null);
@@ -627,7 +672,7 @@
      * @override
      * @param {string} fileSystemId
      * @param {string} registeredName
-     * @return {?DOMFileSystem}
+     * @return {?FileSystem}
      */
     isolatedFileSystem(fileSystemId, registeredName) {
       return DevToolsHost.isolatedFileSystem(fileSystemId, registeredName);
@@ -889,7 +934,7 @@
      * @param {number} actionCode
      */
     recordActionTaken(actionCode) {
-      this.recordEnumeratedHistogram('DevTools.ActionTaken', actionCode, 100);
+      // Do not record actions, as that may crash the DevTools renderer.
     }
 
     /**
@@ -897,7 +942,7 @@
      * @param {number} panelCode
      */
     recordPanelShown(panelCode) {
-      this.recordEnumeratedHistogram('DevTools.PanelShown', panelCode, 20);
+      // Do not record actions, as that may crash the DevTools renderer.
     }
   };
 
@@ -942,7 +987,7 @@
       'emulation.deviceScaleFactor',
       'emulation.deviceUA',
       'emulation.deviceWidth',
-      'emulation.geolocationOverride',
+      'emulation.locationOverride',
       'emulation.showDeviceMode',
       'emulation.showRulers',
       'enableAsyncStackTraces',
@@ -961,7 +1006,6 @@
       'hideCollectedPromises',
       'hideNetworkMessages',
       'highlightNodeOnHoverInOverlay',
-      'highResolutionCpuProfiling',
       'inlineVariableValues',
       'Inspector.drawerSplitView',
       'Inspector.drawerSplitViewState',
@@ -1279,7 +1323,7 @@
       };
 
       Object.defineProperty(HTMLSlotElement.prototype, 'select', {
-        async set(selector) {
+        set(selector) {
           this.name = selector;
         }
       });
